@@ -2,7 +2,7 @@
    Copyright (C) 2007, 2008 Matthew Woehlke <mw_triad@users.sourceforge.net>
    Copyright (C) 2001-2003 Christoph Cullmann <cullmann@kde.org>
    Copyright (C) 2002, 2003 Anders Lund <anders.lund@lund.tdcadsl.dk>
-   Copyright (C) 2012 Dominik Haumann <dhaumann kde org>
+   Copyright (C) 2012-2018 Dominik Haumann <dhaumann@kde.org>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -86,31 +86,31 @@ QVector<KateColorItem> KateSchemaConfigColorTab::colorItemList() const
     ci.category = i18n("Editor Background Colors");
 
     ci.name = i18n("Text Area");
-    ci.key = QLatin1String("Color Background");
+    ci.key = QStringLiteral("Color Background");
     ci.whatsThis = i18n("<p>Sets the background color of the editing area.</p>");
     ci.defaultColor = colors.color(Kate::Background);
     items.append(ci);
 
     ci.name = i18n("Selected Text");
-    ci.key = QLatin1String("Color Selection");
+    ci.key = QStringLiteral("Color Selection");
     ci.whatsThis = i18n("<p>Sets the background color of the selection.</p><p>To set the text color for selected text, use the &quot;<b>Configure Highlighting</b>&quot; dialog.</p>");
     ci.defaultColor = colors.color(Kate::SelectionBackground);
     items.append(ci);
 
     ci.name = i18n("Current Line");
-    ci.key = QLatin1String("Color Highlighted Line");
+    ci.key = QStringLiteral("Color Highlighted Line");
     ci.whatsThis = i18n("<p>Sets the background color of the currently active line, which means the line where your cursor is positioned.</p>");
     ci.defaultColor = colors.color(Kate::HighlightedLineBackground);
     items.append(ci);
 
     ci.name = i18n("Search Highlight");
-    ci.key = QLatin1String("Color Search Highlight");
+    ci.key = QStringLiteral("Color Search Highlight");
     ci.whatsThis = i18n("<p>Sets the background color of search results.</p>");
     ci.defaultColor = colors.color(Kate::SearchHighlight);
     items.append(ci);
 
     ci.name = i18n("Replace Highlight");
-    ci.key = QLatin1String("Color Replace Highlight");
+    ci.key = QStringLiteral("Color Replace Highlight");
     ci.whatsThis = i18n("<p>Sets the background color of replaced text.</p>");
     ci.defaultColor = colors.color(Kate::ReplaceHighlight);
     items.append(ci);
@@ -121,43 +121,49 @@ QVector<KateColorItem> KateSchemaConfigColorTab::colorItemList() const
     ci.category = i18n("Icon Border");
 
     ci.name = i18n("Background Area");
-    ci.key = QLatin1String("Color Icon Bar");
+    ci.key = QStringLiteral("Color Icon Bar");
     ci.whatsThis = i18n("<p>Sets the background color of the icon border.</p>");
     ci.defaultColor = colors.color(Kate::IconBar);
     items.append(ci);
 
     ci.name = i18n("Line Numbers");
-    ci.key = QLatin1String("Color Line Number");
+    ci.key = QStringLiteral("Color Line Number");
     ci.whatsThis = i18n("<p>This color will be used to draw the line numbers (if enabled).</p>");
     ci.defaultColor = colors.color(Kate::LineNumber);
     items.append(ci);
 
+    ci.name = i18n("Current Line Number");
+    ci.key = QStringLiteral("Color Current Line Number");
+    ci.whatsThis = i18n("<p>This color will be used to draw the number of the current line (if enabled).</p>");
+    ci.defaultColor = colors.color(Kate::CurrentLineNumber);
+    items.append(ci);
+
     ci.name = i18n("Separator");
-    ci.key = QLatin1String("Color Separator");
+    ci.key = QStringLiteral("Color Separator");
     ci.whatsThis = i18n("<p>This color will be used to draw the line between line numbers and the icon borders, if both are enabled.</p>");
     ci.defaultColor = colors.color(Kate::Separator);
     items.append(ci);
 
     ci.name = i18n("Word Wrap Marker");
-    ci.key = QLatin1String("Color Word Wrap Marker");
+    ci.key = QStringLiteral("Color Word Wrap Marker");
     ci.whatsThis = i18n("<p>Sets the color of Word Wrap-related markers:</p><dl><dt>Static Word Wrap</dt><dd>A vertical line which shows the column where text is going to be wrapped</dd><dt>Dynamic Word Wrap</dt><dd>An arrow shown to the left of visually-wrapped lines</dd></dl>");
     ci.defaultColor = colors.color(Kate::WordWrapMarker);
     items.append(ci);
 
     ci.name = i18n("Code Folding");
-    ci.key = QLatin1String("Color Code Folding");
+    ci.key = QStringLiteral("Color Code Folding");
     ci.whatsThis = i18n("<p>Sets the color of the code folding bar.</p>");
     ci.defaultColor = colors.color(Kate::CodeFolding);
     items.append(ci);
 
     ci.name = i18n("Modified Lines");
-    ci.key = QLatin1String("Color Modified Lines");
+    ci.key = QStringLiteral("Color Modified Lines");
     ci.whatsThis = i18n("<p>Sets the color of the line modification marker for modified lines.</p>");
     ci.defaultColor = colors.color(Kate::ModifiedLine);
     items.append(ci);
 
     ci.name = i18n("Saved Lines");
-    ci.key = QLatin1String("Color Saved Lines");
+    ci.key = QStringLiteral("Color Saved Lines");
     ci.whatsThis = i18n("<p>Sets the color of the line modification marker for saved lines.</p>");
     ci.defaultColor = colors.color(Kate::SavedLine);
     items.append(ci);
@@ -168,25 +174,25 @@ QVector<KateColorItem> KateSchemaConfigColorTab::colorItemList() const
     ci.category = i18n("Text Decorations");
 
     ci.name = i18n("Spelling Mistake Line");
-    ci.key = QLatin1String("Color Spelling Mistake Line");
+    ci.key = QStringLiteral("Color Spelling Mistake Line");
     ci.whatsThis = i18n("<p>Sets the color of the line that is used to indicate spelling mistakes.</p>");
     ci.defaultColor = colors.color(Kate::SpellingMistakeLine);
     items.append(ci);
 
     ci.name = i18n("Tab and Space Markers");
-    ci.key = QLatin1String("Color Tab Marker");
+    ci.key = QStringLiteral("Color Tab Marker");
     ci.whatsThis = i18n("<p>Sets the color of the tabulator marks.</p>");
     ci.defaultColor = colors.color(Kate::TabMarker);
     items.append(ci);
 
     ci.name = i18n("Indentation Line");
-    ci.key = QLatin1String("Color Indentation Line");
+    ci.key = QStringLiteral("Color Indentation Line");
     ci.whatsThis = i18n("<p>Sets the color of the vertical indentation lines.</p>");
     ci.defaultColor = colors.color(Kate::IndentationLine);
     items.append(ci);
 
     ci.name = i18n("Bracket Highlight");
-    ci.key = QLatin1String("Color Highlighted Bracket");
+    ci.key = QStringLiteral("Color Highlighted Bracket");
     ci.whatsThis = i18n("<p>Sets the bracket matching color. This means, if you place the cursor e.g. at a <b>(</b>, the matching <b>)</b> will be highlighted with this color.</p>");
     ci.defaultColor = colors.color(Kate::HighlightedBracket);
     items.append(ci);
@@ -222,22 +228,22 @@ QVector<KateColorItem> KateSchemaConfigColorTab::colorItemList() const
     ci.whatsThis = QString(); // TODO: add whatsThis for text templates
 
     ci.name = i18n("Background");
-    ci.key = QLatin1String("Color Template Background");
+    ci.key = QStringLiteral("Color Template Background");
     ci.defaultColor = colors.color(Kate::TemplateBackground);
     items.append(ci);
 
     ci.name = i18n("Editable Placeholder");
-    ci.key = QLatin1String("Color Template Editable Placeholder");
+    ci.key = QStringLiteral("Color Template Editable Placeholder");
     ci.defaultColor = colors.color(Kate::TemplateEditablePlaceholder);
     items.append(ci);
 
     ci.name = i18n("Focused Editable Placeholder");
-    ci.key = QLatin1String("Color Template Focused Editable Placeholder");
+    ci.key = QStringLiteral("Color Template Focused Editable Placeholder");
     ci.defaultColor = colors.color(Kate::TemplateFocusedEditablePlaceholder);
     items.append(ci);
 
     ci.name = i18n("Not Editable Placeholder");
-    ci.key = QLatin1String("Color Template Not Editable Placeholder");
+    ci.key = QStringLiteral("Color Template Not Editable Placeholder");
     ci.defaultColor = colors.color(Kate::TemplateNotEditablePlaceholder);
     items.append(ci);
 
@@ -249,7 +255,7 @@ QVector<KateColorItem> KateSchemaConfigColorTab::colorItemList() const
 
 void KateSchemaConfigColorTab::schemaChanged(const QString &newSchema)
 {
-    // save curent schema
+    // save current schema
     if (!m_currentSchema.isEmpty()) {
         if (m_schemas.contains(m_currentSchema)) {
             m_schemas.remove(m_currentSchema); // clear this color schema
@@ -318,8 +324,8 @@ void KateSchemaConfigColorTab::importSchema(KConfigGroup &config)
 
 void KateSchemaConfigColorTab::exportSchema(KConfigGroup &config)
 {
-    QVector<KateColorItem> items = ui->colorItems();
-    foreach (const KateColorItem &item, items) {
+    const QVector<KateColorItem> items = ui->colorItems();
+    for (const KateColorItem &item : items) {
         QColor c = item.useDefault ? item.defaultColor : item.color;
         config.writeEntry(item.key, c);
     }
@@ -331,9 +337,6 @@ void KateSchemaConfigColorTab::apply()
     QMap<QString, QVector<KateColorItem> >::Iterator it;
     for (it =  m_schemas.begin(); it !=  m_schemas.end(); ++it) {
         KConfigGroup config = KTextEditor::EditorPrivate::self()->schemaManager()->schema(it.key());
-        qCDebug(LOG_PART) << "writing 'Color' tab: scheme =" << it.key()
-                          << "and config group =" << config.name();
-
         foreach (const KateColorItem &item, m_schemas[it.key()]) {
             if (item.useDefault) {
                 config.deleteEntry(item.key);
@@ -371,12 +374,12 @@ void KateSchemaConfigColorTab::reload()
 
 QColor KateSchemaConfigColorTab::backgroundColor() const
 {
-    return ui->findColor(QLatin1String("Color Background"));
+    return ui->findColor(QStringLiteral("Color Background"));
 }
 
 QColor KateSchemaConfigColorTab::selectionColor() const
 {
-    return ui->findColor(QLatin1String("Color Selection"));
+    return ui->findColor(QStringLiteral("Color Selection"));
 }
 //END KateSchemaConfigColorTab
 
@@ -587,7 +590,7 @@ void KateSchemaConfigDefaultStylesTab::showEvent(QShowEvent *event)
 {
     if (!event->spontaneous() && !m_currentSchema.isEmpty()) {
         KateAttributeList *l = attributeList(m_currentSchema);
-        Q_ASSERT(l != 0);
+        Q_ASSERT(l != nullptr);
         updateColorPalette(l->at(0)->foreground().color());
     }
 
@@ -628,11 +631,11 @@ KateSchemaConfigHighlightTab::KateSchemaConfigHighlightTab(KateSchemaConfigDefau
 
     headerLayout->addStretch();
 
-    for (int i = 0; i < KateHlManager::self()->highlights(); i++) {
-        if (KateHlManager::self()->hlSection(i).length() > 0) {
-            hlCombo->addItem(KateHlManager::self()->hlSection(i) + QLatin1String("/") + KateHlManager::self()->hlNameTranslated(i));
+    for (const auto &hl : KateHlManager::self()->modeList()) {
+        if (hl.section().length() > 0) {
+            hlCombo->addItem(hl.section() + QLatin1Char('/') + hl.translatedName());
         } else {
-            hlCombo->addItem(KateHlManager::self()->hlNameTranslated(i));
+            hlCombo->addItem(hl.translatedName());
         }
     }
     hlCombo->setCurrentIndex(0);
@@ -676,19 +679,17 @@ void KateSchemaConfigHighlightTab::hlChanged(int z)
 
 bool KateSchemaConfigHighlightTab::loadAllHlsForSchema(const QString &schema)
 {
-    QProgressDialog progress(i18n("Loading all highlightings for schema"), QString(), 0, KateHlManager::self()->highlights(), this);
+    QProgressDialog progress(i18n("Loading all highlightings for schema"), QString(), 0, KateHlManager::self()->modeList().size(), this);
     progress.setWindowModality(Qt::WindowModal);
-    for (int i = 0; i < KateHlManager::self()->highlights(); ++i) {
+    for (int i = 0; i < KateHlManager::self()->modeList().size(); ++i) {
         if (!m_hlDict[schema].contains(i)) {
-            qCDebug(LOG_PART) << "NEW HL, create list";
-
-            QList<KTextEditor::Attribute::Ptr> list;
+            QVector<KTextEditor::Attribute::Ptr> list;
             KateHlManager::self()->getHl(i)->getKateExtendedAttributeListCopy(schema, list);
             m_hlDict[schema].insert(i, list);
         }
         progress.setValue(progress.value() + 1);
     }
-    progress.setValue(KateHlManager::self()->highlights());
+    progress.setValue(KateHlManager::self()->modeList().size());
     return true;
 }
 
@@ -696,20 +697,14 @@ void KateSchemaConfigHighlightTab::schemaChanged(const QString &schema)
 {
     m_schema = schema;
 
-    qCDebug(LOG_PART) << "NEW SCHEMA: " << m_schema << " NEW HL: " << m_hl;
-
     m_styles->clear();
 
     if (!m_hlDict.contains(m_schema)) {
-        qCDebug(LOG_PART) << "NEW SCHEMA, create dict";
-
-        m_hlDict.insert(schema, QHash<int, QList<KTextEditor::Attribute::Ptr> >());
+        m_hlDict.insert(schema, QHash<int, QVector<KTextEditor::Attribute::Ptr> >());
     }
 
     if (!m_hlDict[m_schema].contains(m_hl)) {
-        qCDebug(LOG_PART) << "NEW HL, create list";
-
-        QList<KTextEditor::Attribute::Ptr> list;
+        QVector<KTextEditor::Attribute::Ptr> list;
         KateHlManager::self()->getHl(m_hl)->getKateExtendedAttributeListCopy(m_schema, list);
         m_hlDict[m_schema].insert(m_hl, list);
     }
@@ -720,13 +715,11 @@ void KateSchemaConfigHighlightTab::schemaChanged(const QString &schema)
     updateColorPalette(l->at(0)->foreground().color());
 
     QHash<QString, QTreeWidgetItem *> prefixes;
-    QList<KTextEditor::Attribute::Ptr>::ConstIterator it = m_hlDict[m_schema][m_hl].constBegin();
+    QVector<KTextEditor::Attribute::Ptr>::ConstIterator it = m_hlDict[m_schema][m_hl].constBegin();
     while (it != m_hlDict[m_schema][m_hl].constEnd()) {
         const KTextEditor::Attribute::Ptr itemData = *it;
         Q_ASSERT(itemData);
 
-        qCDebug(LOG_PART) << "insert items " << itemData->name();
-
         // All stylenames have their language mode prefixed, e.g. HTML:Comment
         // split them and put them into nice substructures.
         int c = itemData->name().indexOf(QLatin1Char(':'));
@@ -770,10 +763,10 @@ void KateSchemaConfigHighlightTab::reload()
 
 void KateSchemaConfigHighlightTab::apply()
 {
-    QMutableHashIterator<QString, QHash<int, QList<KTextEditor::Attribute::Ptr> > > it = m_hlDict;
+    QMutableHashIterator<QString, QHash<int, QVector<KTextEditor::Attribute::Ptr> > > it = m_hlDict;
     while (it.hasNext()) {
         it.next();
-        QMutableHashIterator<int, QList<KTextEditor::Attribute::Ptr> > it2 = it.value();
+        QMutableHashIterator<int, QVector<KTextEditor::Attribute::Ptr> > it2 = it.value();
         while (it2.hasNext()) {
             it2.next();
             KateHlManager::self()->getHl(it2.key())->setKateExtendedAttributeList(it.key(), it2.value());
@@ -790,7 +783,7 @@ void KateSchemaConfigHighlightTab::importHl(const QString &fromSchemaName, QStri
 {
     QString schemaNameForLoading(fromSchemaName);
     QString hlName;
-    bool doManage = (cfg == 0);
+    bool doManage = (cfg == nullptr);
     if (schema.isEmpty()) {
         schema = m_schema;
     }
@@ -799,12 +792,12 @@ void KateSchemaConfigHighlightTab::importHl(const QString &fromSchemaName, QStri
         QString srcName = QFileDialog::getOpenFileName(this,
                           i18n("Importing colors for single highlighting"),
                           KateHlManager::self()->getHl(hl)->name() + QLatin1String(".katehlcolor"),
-                          QString::fromLatin1("*.katehlcolor|%1").arg(i18n("Kate color schema")));
+                          QStringLiteral("%1 (*.katehlcolor)").arg(i18n("Kate color schema")));
 
-        qCDebug(LOG_PART) << "hl file to open " << srcName;
         if (srcName.isEmpty()) {
             return;
         }
+
         cfg = new KConfig(srcName, KConfig::SimpleConfig);
         KConfigGroup grp(cfg, "KateHLColors");
         hlName = grp.readEntry("highlight", QString());
@@ -819,7 +812,6 @@ void KateSchemaConfigHighlightTab::importHl(const QString &fromSchemaName, QStri
             schemaNameForLoading = QString();
         } else {
             hl = KateHlManager::self()->nameFind(hlName);
-            qCDebug(LOG_PART) << hlName << "--->" << hl;
             if (hl == -1) {
                 //hl not found
                 KMessageBox::information(
@@ -834,7 +826,7 @@ void KateSchemaConfigHighlightTab::importHl(const QString &fromSchemaName, QStri
 
     if ((hl != -1) && (!schemaNameForLoading.isEmpty())) {
 
-        QList<KTextEditor::Attribute::Ptr> list;
+        QVector<KTextEditor::Attribute::Ptr> list;
         KateHlManager::self()->getHl(hl)->getKateExtendedAttributeListCopy(schemaNameForLoading, list, cfg);
         KateHlManager::self()->getHl(hl)->setKateExtendedAttributeList(schema, list);
         m_hlDict[schema].insert(hl, list);
@@ -843,7 +835,7 @@ void KateSchemaConfigHighlightTab::importHl(const QString &fromSchemaName, QStri
     if (cfg && doManage) {
         apply();
         delete cfg;
-        cfg = 0;
+        cfg = nullptr;
         if ((hl != -1) && (!schemaNameForLoading.isEmpty())) {
             hlChanged(m_hl);
             KMessageBox::information(
@@ -857,7 +849,7 @@ void KateSchemaConfigHighlightTab::importHl(const QString &fromSchemaName, QStri
 
 void KateSchemaConfigHighlightTab::exportHl(QString schema, int hl, KConfig *cfg)
 {
-    bool doManage = (cfg == 0);
+    bool doManage = (cfg == nullptr);
     if (schema.isEmpty()) {
         schema = m_schema;
     }
@@ -865,12 +857,12 @@ void KateSchemaConfigHighlightTab::exportHl(QString schema, int hl, KConfig *cfg
         hl = m_hl;
     }
 
-    QList<KTextEditor::Attribute::Ptr> items = m_hlDict[schema][hl];
+    QVector<KTextEditor::Attribute::Ptr> items = m_hlDict[schema][hl];
     if (doManage)  {
         QString destName = QFileDialog::getSaveFileName(this,
                            i18n("Exporting colors for single highlighting: %1", KateHlManager::self()->getHl(hl)->name()),
                            KateHlManager::self()->getHl(hl)->name() + QLatin1String(".katehlcolor"),
-                           QString::fromLatin1("*.katehlcolor|%1").arg(i18n("Kate color schema")));
+                           QStringLiteral("%1 (*.katehlcolor)").arg(i18n("Kate color schema")));
 
         if (destName.isEmpty()) {
             return;
@@ -895,7 +887,7 @@ void KateSchemaConfigHighlightTab::showEvent(QShowEvent *event)
 {
     if (!event->spontaneous()) {
         KateAttributeList *l = m_defaults->attributeList(m_schema);
-        Q_ASSERT(l != 0);
+        Q_ASSERT(l != nullptr);
         updateColorPalette(l->at(0)->foreground().color());
     }
 
@@ -909,7 +901,7 @@ KateSchemaConfigPage::KateSchemaConfigPage(QWidget *parent)
       m_currentSchema(-1)
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     // header
     QHBoxLayout *headerLayout = new QHBoxLayout;
@@ -989,7 +981,7 @@ void KateSchemaConfigPage::exportFullSchema()
     QString destName = QFileDialog::getSaveFileName(this,
                        i18n("Exporting color schema: %1", currentSchemaName),
                        currentSchemaName + QLatin1String(".kateschema"),
-                       QString::fromLatin1("*.kateschema|%1").arg(i18n("Kate color schema")));
+                       QStringLiteral("%1 (*.kateschema)").arg(i18n("Kate color schema")));
 
     if (destName.isEmpty()) {
         return;
@@ -1016,12 +1008,12 @@ void KateSchemaConfigPage::exportFullSchema()
     QStringList hlList;
     m_highlightTab->loadAllHlsForSchema(m_currentSchema);
 
-    QList<int> hls = m_highlightTab->hlsForSchema(m_currentSchema);
+    const QList<int> hls = m_highlightTab->hlsForSchema(m_currentSchema);
 
     int cnt = 0;
     QProgressDialog progress(i18n("Exporting schema"), QString(), 0, hls.count(), this);
     progress.setWindowModality(Qt::WindowModal);
-    foreach (int hl, hls) {
+    for (int hl : hls) {
         hlList << KateHlManager::self()->getHl(hl)->name();
         m_highlightTab->exportHl(m_currentSchema, hl, &cfg);
         progress.setValue(++cnt);
@@ -1120,7 +1112,7 @@ void KateSchemaConfigPage::importFullSchema()
     const QString srcName = QFileDialog::getOpenFileName(this,
                             i18n("Importing Color Schema"),
                             QString(),
-                            QString::fromLatin1("*.kateschema|%1").arg(i18n("Kate color schema")));
+                            QStringLiteral("%1 (*.kateschema)").arg(i18n("Kate color schema")));
 
     if (srcName.isEmpty()) {
         return;
@@ -1157,7 +1149,6 @@ void KateSchemaConfigPage::importFullSchema()
 
     // Finally, the correct schema is activated.
     // Next,  start importing.
-    qCDebug(LOG_PART) << "Importing schema: " << schemaName;
 
     //
     // import editor Colors (background, ...)
@@ -1179,23 +1170,20 @@ void KateSchemaConfigPage::importFullSchema()
     // import all Highlighting Text Styles
     //
     // create mapping from highlighting name to internal id
-    const int hlCount = KateHlManager::self()->highlights();
+    const int hlCount = KateHlManager::self()->modeList().size();
     QHash<QString, int> nameToId;
     for (int i = 0; i < hlCount; ++i) {
-        nameToId.insert(KateHlManager::self()->hlName(i), i);
+        nameToId.insert(KateHlManager::self()->modeList().at(i).name(), i);
     }
 
     // may take some time, as we have > 200 highlightings
     int cnt = 0;
     QProgressDialog progress(i18n("Importing schema"), QString(), 0, highlightings.count(), this);
     progress.setWindowModality(Qt::WindowModal);
-    foreach (const QString &hl, highlightings) {
+    for (const QString &hl : highlightings) {
         if (nameToId.contains(hl)) {
             const int i = nameToId[hl];
             m_highlightTab->importHl(fromSchemaName, schemaName, i, &cfg);
-            qCDebug(LOG_PART) << "hl imported:" << hl;
-        } else {
-            qCDebug(LOG_PART) << "could not import hl, hl unknown:" << hl;
         }
         progress.setValue(++cnt);
     }
@@ -1218,7 +1206,7 @@ void KateSchemaConfigPage::apply()
     KTextEditor::EditorPrivate::self()->schemaManager()->config().reparseConfiguration();
 
     // clear all attributes
-    for (int i = 0; i < KateHlManager::self()->highlights(); ++i) {
+    for (int i = 0; i < KateHlManager::self()->modeList().size(); ++i) {
         KateHlManager::self()->getHl(i)->clearAttributeArrays();
     }
 
@@ -1262,8 +1250,8 @@ void KateSchemaConfigPage::refillCombos(const QString &schemaName, const QString
     // reinitialize combo boxes
     schemaCombo->clear();
     defaultSchemaCombo->clear();
-    QList<KateSchema> schemaList = KTextEditor::EditorPrivate::self()->schemaManager()->list();
-    foreach (const KateSchema &s, schemaList) {
+    const QList<KateSchema> schemaList = KTextEditor::EditorPrivate::self()->schemaManager()->list();
+    for (const KateSchema &s : schemaList) {
         schemaCombo->addItem(s.translatedName(), s.rawName);
         defaultSchemaCombo->addItem(s.translatedName(), s.rawName);
     }
@@ -1306,7 +1294,6 @@ void KateSchemaConfigPage::deleteSchema()
 
     if (KTextEditor::EditorPrivate::self()->schemaManager()->schemaData(schemaNameToDelete).shippedDefaultSchema) {
         // Default and Printing schema cannot be deleted.
-        qCDebug(LOG_PART) << "default and printing schema cannot be deleted";
         return;
     }
 
@@ -1314,9 +1301,9 @@ void KateSchemaConfigPage::deleteSchema()
     KTextEditor::EditorPrivate::self()->schemaManager()->config().deleteGroup(schemaNameToDelete);
 
     // fallback to Default schema
-    schemaCombo->setCurrentIndex(schemaCombo->findData(QVariant(QString::fromLatin1("Normal"))));
+    schemaCombo->setCurrentIndex(schemaCombo->findData(QVariant(QStringLiteral("Normal"))));
     if (defaultSchemaCombo->currentIndex() == defaultSchemaCombo->findData(schemaNameToDelete)) {
-        defaultSchemaCombo->setCurrentIndex(defaultSchemaCombo->findData(QVariant(QString::fromLatin1("Normal"))));
+        defaultSchemaCombo->setCurrentIndex(defaultSchemaCombo->findData(QVariant(QStringLiteral("Normal"))));
     }
 
     // remove schema from combo box
@@ -1386,7 +1373,7 @@ QString KateSchemaConfigPage::fullName() const
 
 QIcon KateSchemaConfigPage::icon() const
 {
-    return QIcon::fromTheme(QLatin1String("preferences-desktop-color"));
+    return QIcon::fromTheme(QStringLiteral("preferences-desktop-color"));
 }
 
 //END KateSchemaConfigPage
