@@ -27,6 +27,8 @@
 #include <ktexteditor/document.h>
 
 #include "katepartdebug.h"
+
+#include <QRegularExpression>
 //END  includes
 
 //BEGIN d'tor, c'tor
@@ -53,7 +55,7 @@ KTextEditor::Range KatePlainTextSearch::search(const QString &text, const KTextE
     // abuse regex for whole word plaintext search
     if (m_wholeWords) {
         // escape dot and friends
-        const QString workPattern = QStringLiteral("\\b%1\\b").arg(QRegExp::escape(text));
+        const QString workPattern = QStringLiteral("\\b%1\\b").arg(QRegularExpression::escape(text));
 
         return KateRegExpSearch(m_document, m_caseSensitivity).search(workPattern, inputRange, backwards).at(0);
     }
@@ -63,7 +65,7 @@ KTextEditor::Range KatePlainTextSearch::search(const QString &text, const KTextE
     }
 
     // split multi-line needle into single lines
-    const QStringList needleLines = text.split(QStringLiteral("\n"));
+    const auto needleLines = text.splitRef(QLatin1Char('\n'));
 
     if (needleLines.count() > 1) {
         // multi-line plaintext search (both forwards or backwards)
@@ -77,7 +79,7 @@ KTextEditor::Range KatePlainTextSearch::search(const QString &text, const KTextE
             const int startCol = m_document->lineLength(j) - needleLines[0].length();
             for (int k = 0; k < needleLines.count(); k++) {
                 // which lines to compare
-                const QString &needleLine = needleLines[k];
+                const QStringRef &needleLine = needleLines[k];
                 const QString &hayLine = m_document->line(j + k);
 
                 // position specific comparison (first, middle, last)
