@@ -387,7 +387,7 @@ void KateHighlighting::getKateExtendedAttributeListCopy(const QString &schema, Q
 
     list.clear();
 
-    foreach (const KTextEditor::Attribute::Ptr &attribute, attributes) {
+    for (const KTextEditor::Attribute::Ptr &attribute : qAsConst(attributes)) {
         list.append(KTextEditor::Attribute::Ptr(new KTextEditor::Attribute(*attribute.data())));
     }
 }
@@ -461,7 +461,7 @@ KTextEditor::DefaultStyle KateHighlighting::defaultStyleForAttribute(int attr) c
 QString KateHighlighting::nameForAttrib(int attrib) const
 {
     const auto &format = m_formats.at(sanitizeFormatIndex(attrib));
-    return m_propertiesForFormat.at(sanitizeFormatIndex(attrib))->definition.name() + QLatin1Char(':') + QString(format.isValid() ? format.name() : QLatin1String("Normal"));
+    return m_propertiesForFormat.at(sanitizeFormatIndex(attrib))->definition.name() + QLatin1Char(':') + QString(format.isValid() ? format.name() : QStringLiteral("Normal"));
 }
 
 bool KateHighlighting::isInWord(QChar c, int attrib) const
@@ -546,8 +546,8 @@ QVector<KTextEditor::Attribute::Ptr> KateHighlighting::attributesForDefinition(c
         KTextEditor::Attribute::Ptr newAttribute(new KTextEditor::Attribute(nameForAttrib(array.size()), textStyleToDefaultStyle(format.textStyle())));
 
         /**
-         * NOTE: if "theme()" returns an empty theme, only the
-         * attribute styles set in the XML files will be applied here
+         * NOTE: if "theme()" returns an empty/invalid theme, only the
+         * attribute styles set in the XML files will be applied here.
          */
         if (format.hasTextColor(theme())) {
             newAttribute->setForeground(format.textColor(theme()));
@@ -559,20 +559,43 @@ QVector<KTextEditor::Attribute::Ptr> KateHighlighting::attributesForDefinition(c
             newAttribute->setSelectedBackground(format.selectedBackgroundColor(theme()));
         }
 
-        if (format.isBold(theme())) {
-            newAttribute->setFontBold(true);
+        /**
+         * Apply attributes set in the syntax definition XML files.
+         * This overwrites the default theme and the theme customized by the user.
+         *
+         * It's allowed to turn off the bold, italic, underline and strikeout
+         * attributes in the XML files (see bug #143399).
+         */
+        if (format.hasBoldOverride()) {
+            if (format.isBold(theme())) {
+                newAttribute->setFontBold(true);
+            } else {
+                newAttribute->setFontBold(false);
+            }
         }
 
-        if (format.isItalic(theme())) {
-            newAttribute->setFontItalic(true);
+        if (format.hasItalicOverride()) {
+            if (format.isItalic(theme())) {
+                newAttribute->setFontItalic(true);
+            } else {
+                newAttribute->setFontItalic(false);
+            }
         }
 
-        if (format.isUnderline(theme())) {
-            newAttribute->setFontUnderline(true);
+        if (format.hasUnderlineOverride()) {
+            if (format.isUnderline(theme())) {
+                newAttribute->setFontUnderline(true);
+            } else {
+                newAttribute->setFontUnderline(false);
+            }
         }
 
-        if (format.isStrikeThrough(theme())) {
-            newAttribute->setFontStrikeOut(true);
+        if (format.hasStrikeThroughOverride()) {
+            if (format.isStrikeThrough(theme())) {
+                newAttribute->setFontStrikeOut(true);
+            } else {
+                newAttribute->setFontStrikeOut(false);
+            }
         }
 
         newAttribute->setSkipSpellChecking(format.spellCheck());
